==> keyclic_sdk_api-2.2.12.tar.gz: lib/model/occupant_links.dart <==
part of keyclic_sdk_api.api;

class OccupantLinks {
  OccupantLinks({
    this.person,
    this.place,
    this.self,
  });

  factory OccupantLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return OccupantLinks(
      person: OccupantLinksPerson.fromJson(json['person']),
      place: OccupantLinksPlace.fromJson(json['place']),
      self: OccupantLinksSelf.fromJson(json['self']),
    );
  }

  OccupantLinksPerson person;

  OccupantLinksPlace place;

  OccupantLinksSelf self;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is OccupantLinks &&
        runtimeType == other.runtimeType &&
        person == other.person &&
        place == other.place &&
        self == other.self;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= person?.hashCode ?? 0;
    hashCode ^= place?.hashCode ?? 0;
    hashCode ^= self?.hashCode ?? 0;

    return hashCode;
  }

  static List<OccupantLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? <OccupantLinks>[]
        : json.map((dynamic value) => OccupantLinks.fromJson(value)).toList();
  }

  static Map<String, OccupantLinks> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, OccupantLinks>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = OccupantLinks.fromJson(value));
    }

    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      if (person != null) 'person': person,
      if (place != null) 'place': place,
      if (self != null) 'self': self,
    };
  }

  @override
  String toString() {
    return 'OccupantLinks[person=$person, place=$place, self=$self, ]';
  }
}

==> keyclic_sdk_api-2.3.3.tar.gz: lib/model/occupant_links.dart <==
part of keyclic_sdk_api.api;

class OccupantLinks {
  OccupantLinks({
    this.member,
    this.place,
    this.self,
  });

  factory OccupantLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return OccupantLinks(
      member: OccupantLinksMember.fromJson(json['member']),
      place: OccupantLinksPlace.fromJson(json['place']),
      self: OccupantLinksSelf.fromJson(json['self']),
    );
  }

  OccupantLinksMember member;

  OccupantLinksPlace place;

  OccupantLinksSelf self;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is OccupantLinks &&
        runtimeType == other.runtimeType &&
        member == other.member &&
        place == other.place &&
        self == other.self;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= member?.hashCode ?? 0;
    hashCode ^= place?.hashCode ?? 0;
    hashCode ^= self?.hashCode ?? 0;

    return hashCode;
  }

  static List<OccupantLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? <OccupantLinks>[]
        : json.map((dynamic value) => OccupantLinks.fromJson(value)).toList();
  }

  static Map<String, OccupantLinks> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, OccupantLinks>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = OccupantLinks.fromJson(value));
    }

    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      if (member != null) 'member': member,
      if (place != null) 'place': place,
      if (self != null) 'self': self,
    };
  }

  @override
  String toString() {
    return 'OccupantLinks[member=$member, place=$place, self=$self, ]';
  }
}
